@@ -360,9 +360,9 @@ def sls_sfsp(stage, region, chdir_path):
 
 def populate_git_traits(app, branch, commit, version, author):
     app["branch"] = branch if branch else git_branch
-    app["commit"] = commit if branch else git_commit
-    app["author"] = author if branch else git_author
-    app["version"] = version if branch else ''
+    app["commit"] = commit if commit else git_commit
+    app["author"] = author if author else git_author
+    app["version"] = version if version else ''
     return app
 
 def cloudfront_distribution_exists(distribution_id):
@@ -401,7 +401,7 @@ def create_invalidation(distribution_id, paths):
 
 def get_ui_versions(s3_bucket):
     if not s3_bucket_exists_and_not_empty(s3_bucket):
-        logging.warning(f'versions folder in bucket ({s3_bucket}) was not found or it is empty.')
+        logging.warning(f'"versions" folder in bucket ({s3_bucket}) was not found or it is empty.')
         return []
 
     paginator = s3_client.get_paginator('list_objects')
@@ -429,7 +429,7 @@ def s3_bucket_exists_and_not_empty(s3_bucket) -> bool:
         return 'Contents' in resp
     except ClientError as e:
         logging.warning("S3 Client error: %s" % e)
-        return False
+        sys.exit(1)
 
 def s3_sync(source, target, args=''):
     command=f'aws s3 sync {source} {target} {args}'
@@ -934,7 +934,7 @@ def deploy_ui_cmd(stage, s3_bucket, version, distribution_id, invalidate_paths,
         app["pipeline_metadata"]["deploy"]["second_last_version_folder"] = last_versions[1]
         app["pipeline_metadata"]["deploy"]["second_last_version"] = last_versions[1].split('-')[1]
         write_traits_to_file(app, traits_output_file)
-    else:
+    elif last_versions and len(last_versions) == 1:
         app["pipeline_metadata"]["deploy"]["last_version_folder"] = last_versions[0]
         app["pipeline_metadata"]["deploy"]["last_version"] = last_versions[0].split('-')[1]
         write_traits_to_file(app, traits_output_file)
